@@ -20,6 +20,16 @@ def trans_excel_to_csv(excel_path, csv_path, encoding="utf8", gbk_fixing=True):
                 writer.writerow([c.value for c in row])
 
 
+def trans_csv_to_excel(csv_path, excel_path):
+    import openpyxl
+    wb = openpyxl.Workbook()
+    ws = wb.active
+    ws.append(read_csv_head(csv_path))
+    for row in read_csv_rows(csv_path):
+        ws.append(row)
+    wb.save(excel_path)
+
+
 def read_csv_dict(path, encoding=None):
     import csv
     unknown_encoding = "unknown"
@@ -78,6 +88,27 @@ def open_excel(path):
     return xlrd.open_workbook(path)
 
 
+def save_excel_rows(rows, path):
+    import openpyxl
+    wb = openpyxl.Workbook()
+    ws = wb.active
+    for row in rows:
+        ws.append(row)
+    ws.save(path)
+
+
+def save_excel_items(items, path):
+    import openpyxl
+    head = list(items[0].keys())
+    wb = openpyxl.Workbook()
+    ws = wb.active
+    ws.append(head)
+    for item in items:
+        row = [item.get(k, "") for k in head]
+        ws.append(row)
+    ws.save(path)
+
+
 def get_excel_sheet(excel, sheet_name = None):
     sheet_names=excel.sheet_names()
     if sheet_name is None:
